@@ -11,11 +11,20 @@ def get_product_protocol_command(connection_type: str):
 
 def get_stock_protocol_command(connection_type: str):
 	if connection_type.lower() == 'mysql':
-		return 'update openk_semaforo.estoque_produto set data_sincronizacao = now() where codigo_erp_variacao = %s;'
+		return 'update openk_semaforo.estoque_produto set data_sincronizacao = now() where codigo_erp = %s;'
 	elif connection_type.lower() == 'oracle':
-		return 'update openk_semaforo.estoque_produto set data_sincronizacao = TRUNC(SYSDATE) where codigo_erp_variacao = :codigo_erp;'
+		return 'update openk_semaforo.estoque_produto set data_sincronizacao = TRUNC(SYSDATE) where codigo_erp = :codigo_erp;'
 	elif connection_type.lower() == 'sqlserver':
-		return 'update openk_semaforo.estoque_produto set data_sincronizacao = now() where codigo_erp_variacao = %s;'
+		return 'update openk_semaforo.estoque_produto set data_sincronizacao = now() where codigo_erp = %s;'
+
+
+def get_price_protocol_command(connection_type: str):
+	if connection_type.lower() == 'mysql':
+		return 'update openk_semaforo.preco_produto set data_sincronizacao = now() where codigo_erp = %s;'
+	elif connection_type.lower() == 'oracle':
+		return 'update openk_semaforo.preco_produto set data_sincronizacao = TRUNC(SYSDATE) where codigo_erp = :codigo_erp;'
+	elif connection_type.lower() == 'sqlserver':
+		return 'update openk_semaforo.preco_produto set data_sincronizacao = now() where codigo_erp = %s;'
 
 
 def get_command_parameter(connection_type: str, parameters: list):
